[![Build Status](https://www.travis-ci.com/bento-dbaas/dbaas-base-provider.svg?branch=master)](https://www.travis-ci.com/bento-dbaas/dbaas-base-provider) [![codecov](https://codecov.io/gh/bento-dbaas/dbaas-base-provider/branch/master/graph/badge.svg?token=QNH0Q4UVGQ)](https://codecov.io/gh/bento-dbaas/dbaas-base-provider)
